@@ -1,17 +1,16 @@
 from sqlalchemy_declarative_extensions import dialects
 from sqlalchemy_declarative_extensions.alembic import register_alembic_events
-from sqlalchemy_declarative_extensions.grant import Grants
-from sqlalchemy_declarative_extensions.role import Role
-from sqlalchemy_declarative_extensions.role.base import Roles
-from sqlalchemy_declarative_extensions.row import Row, Rows
-from sqlalchemy_declarative_extensions.schema import Schema, Schemas
-
-# isort: split
 from sqlalchemy_declarative_extensions.api import (
     declarative_database,
     declare_database,
     register_sqlalchemy_events,
 )
+from sqlalchemy_declarative_extensions.grant import Grants
+from sqlalchemy_declarative_extensions.role import Role
+from sqlalchemy_declarative_extensions.role.base import Roles
+from sqlalchemy_declarative_extensions.row import Row, Rows
+from sqlalchemy_declarative_extensions.schema import Schema, Schemas
+from sqlalchemy_declarative_extensions.view.base import View, Views, view
 
 __all__ = [
     "declarative_database",
@@ -27,4 +26,7 @@ __all__ = [
     "Roles",
     "Schema",
     "Schemas",
+    "view",
+    "View",
+    "Views",
 ]
